import os
import pandas as pd
import numpy as np
current_path = os.path.dirname(os.path.abspath(__file__))
ua_array = pd.read_pickle(current_path + "\\UA.pkl")
def random_ua():
    """
    获取随机的ua
    """
    ua_ls = np.random.choice(ua_array,1)
    return ua_ls[0]

def get_ua(index=0):
    """
    获取指定索引的ua
    """
    ua_ls = np.random.choice(ua_array, index)
    return ua_ls[0]

if __name__ == '__main__':
    ua = random_ua()
    print(ua)


# -*- coding: utf-8-*-
from setuptools import setup, find_packages
import os, io

here = os.path.abspath(os.path.dirname(__file__))

with io.open(os.path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = '\n' + f.read()

setup(
    # 以下为必需参数
    name='mobile_ua',  # 模块名
    version='1.0.2',  # 当前版本
    description='Randomly obtain the Useragent of the mobile phone',  # 简短描述
    long_description=long_description,
    long_description_content_type='text/markdown',
    author='white.tie',
    author_email='1042798703@qq.com',
    license='MIT',
    url='https://gitee.com/tieyongjie/mobile_ua',
    install_requires=[
        'pandas',
        'numpy'
    ],
    packages=['mobile_ua'],
    package_data={
        'mobile_ua': ['UA.pkl'],
    },
    package_dir={'': 'src'}
)
